The examples in this directory show off various kinds of interactions that are easily
possible using Bokeh, including:

* linked panning/zooming
* linked selection brushing
* hover tooltips
* controlling range bounds
* updating date from an AJAX data source
* using JS callbacks for range updates, widgets, etc.

as well as show more detailed walkthroughs of some specific examples.
